Crate humphrey_json_derive

Crate humphrey_json_derive 

Provides the derive macros for Humphrey JSON.

These macros should only be used from the Humphrey JSON crate itself, never directly from this crate. You can read about their uses in the Humphrey JSON documentation.

Derive Macros

FromJson
Derives the FromJson trait for a type.
IntoJson
Derives the IntoJson trait for a type.