Provides the derive macros for Humphrey JSON.
These macros should only be used from the Humphrey JSON crate itself, never directly from this crate. You can read about their uses in the Humphrey JSON documentation.
Provides the derive macros for Humphrey JSON.
These macros should only be used from the Humphrey JSON crate itself, never directly from this crate. You can read about their uses in the Humphrey JSON documentation.